package com.emato.eoss.manager.authz.common.comm;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.UUID;

/**
 * @author Scott Chen
 * @date 2021-03-16
 */
public class HttpHeaderSupport {

    public static HttpRequestHeader buildOssRequestHeader(HttpServletRequest req, HttpServletResponse resp) {
        HttpRequestHeader mate = new HttpRequestHeader();
        mate.setAuthorization(req.getHeader(HttpHeaders.AUTHORIZATION));
        mate.setContentLength(req.getHeader(HttpHeaders.CONTENT_LENGTH));
        mate.setContentType(req.getHeader(HttpHeaders.CONTENT_TYPE));
        // The RFC-1123 date-time formatter, such as 'Tue, 3 Jun 2008 11:05:30 GMT'
        mate.setDate(req.getHeader(HttpHeaders.DATE));
        mate.setHost(req.getHeader(HttpHeaders.HOST));
        return mate;
    }

    public static HttpServletResponse buildOssResponseHeader(HttpResponseHeader httpResponseHeader, HttpServletRequest req, HttpServletResponse resp) {
        resp.setHeader(HttpHeaders.CONTENT_LENGTH, httpResponseHeader.getContentLength());
        resp.setHeader(HttpHeaders.CONNECTION, httpResponseHeader.getConnection());
        // The RFC-1123 date-time formatter, such as 'Tue, 3 Jun 2008 11:05:30 GMT'
        // resp.setHeader("Date", DateTimeFormatter.RFC_1123_DATE_TIME.format(ZonedDateTime.now()));
        resp.setHeader(HttpHeaders.DATE, new SimpleDateFormat().format(new Date()));

        resp.setHeader(HttpHeaders.ETAG, httpResponseHeader.getETag());
        resp.setHeader("Server", httpResponseHeader.getServer());
        resp.setHeader("x-oss-request-id", UUID.randomUUID().toString());
        return resp;
    }




}
