package com.emato.eoss.manager.authz.common.comm;

import java.io.Serializable;

/**
 * RESTful接口中使用了一些公共请求头
 *
 * @author Scott Chen
 * @date 2021-03-16
 */
public class HttpRequestHeader implements Serializable {
    private static final long serialVersionUID = -4388587992068206792L;

    /**
     * 用于验证请求合法性的认证信息。
     * 默认值：无
     *
     * 使用场景：非匿名请求
     */
    private String authorization;

    /**
     * RFC2616中定义的HTTP请求内容长度。
     * 默认值：无
     *
     * 使用场景：需要向OSS提交数据的请求
     */
    private String contentLength;

    /**
     * RFC2616中定义的HTTP请求内容类型。
     * 默认值：无
     *
     * 使用场景：需要向OSS提交数据的请求
     */
    private String contentType;

    /**
     * The RFC-1123 date-time formatter, such as 'Tue, 3 Jun 2008 11:05:30 GMT'
     *
     * HTTP 1.1协议中规定的GMT时间，例如：Wed, 05 Sep. 2012 23:00:00 GMT
     * 默认值：无
     */
    private String date;

    /**
     * 访问Host值，格式为：<bucketname>.oss-cn-hangzhou.aliyuncs.com。
     * 默认值：无
     */
    private String host;

    public String getAuthorization() {
        return authorization;
    }

    public void setAuthorization(String authorization) {
        this.authorization = authorization;
    }

    public String getContentLength() {
        return contentLength;
    }

    public void setContentLength(String contentLength) {
        this.contentLength = contentLength;
    }

    public String getContentType() {
        return contentType;
    }

    public void setContentType(String contentType) {
        this.contentType = contentType;
    }

    public String getDate() {
        return date;
    }

    public void setDate(String date) {
        this.date = date;
    }

    public String getHost() {
        return host;
    }

    public void setHost(String host) {
        this.host = host;
    }
}
