package com.emato.eoss.manager.authz.common.comm;

import java.io.Serializable;

/**
 * RESTful接口中使用了一些公共响应头
 *
 * @author Scott Chen
 * @date 2021-03-16
 */
public class HttpResponseHeader implements Serializable {
    private static final long serialVersionUID = 2478360627834922277L;

    /**
     * RFC2616中定义的HTTP请求内容长度。
     * 默认值：无
     *
     * 使用场景：需要向OSS提交数据的请求
     */
    private String contentLength;

    /**
     * 标明客户端和OSS服务器之间的链接状态。
     * 有效值：open、close
     * 默认值：无
     */
    private String Connection;

    /**
     * HTTP 1.1协议中规定的GMT时间，例如：Wed, 05 Sep. 2012 23:00:00 GMT
     * 默认值：无
     */
    private String Date;

    /**
     * ETag (entity tag) 在每个Object生成的时候被创建，用于标示一个Object的内容。
     *      对于Put Object请求创建的Object，ETag值是其内容的MD5值；
     *      对于其他方式创建的Object，ETag值是其内容的UUID。ETag值可以用于检查Object内容是否发生变化。
     * 默认值：无
     */
    private String ETag;

    /**
     * 生成Response的服务器。
     *  默认值：OSS
     */
    private String Server;

    /**
     * x-oss-request-id是由OSS创建，并唯一标识这个response的UUID。
     * 如果在使用OSS服务时遇到问题，可以凭借该字段联系OSS工作人员，快速定位问题。
     * 默认值：无
     */
    private String xOssRequestId;

    public String getContentLength() {
        return contentLength;
    }

    public void setContentLength(String contentLength) {
        this.contentLength = contentLength;
    }

    public String getConnection() {
        return Connection;
    }

    public void setConnection(String connection) {
        Connection = connection;
    }

    public String getDate() {
        return Date;
    }

    public void setDate(String date) {
        Date = date;
    }

    public String getETag() {
        return ETag;
    }

    public void setETag(String ETag) {
        this.ETag = ETag;
    }

    public String getServer() {
        return Server;
    }

    public void setServer(String server) {
        Server = server;
    }

    public String getxOssRequestId() {
        return xOssRequestId;
    }

    public void setxOssRequestId(String xOssRequestId) {
        this.xOssRequestId = xOssRequestId;
    }
}
